@@ -1,4 +1,4 @@
-/* $Id: hparser.c,v 2.46 2000/12/04 04:55:42 gisle Exp $
+/* $Id: hparser.c,v 2.49 2000/12/26 08:52:44 gisle Exp $
  *
  * Copyright 1999-2000, Gisle Aas
  * Copyright 1999-2000, Michael A. Chase
@@ -98,12 +98,14 @@ report_event(PSTATE* p_state,
 	    )
 {
   struct p_handler *h;
+  dTHX;
   dSP;
   AV *array;
   STRLEN my_na;
   char *argspec;
   char *s;
 
+#if 0
   if (0) {  /* used for debugging at some point */
     char *s = beg;
     int i;
@@ -136,6 +138,7 @@ report_event(PSTATE* p_state,
 	     tokens[i].end - tokens[i].beg);
     }
   }
+#endif
 
 #ifdef MARKED_SECTION
   if (p_state->ms == MS_IGNORE)
@@ -251,7 +254,7 @@ report_event(PSTATE* p_state,
 	arg = sv_2mortal(newSVpvn(tokens[0].beg,
 				  tokens[0].end - tokens[0].beg));
 	if (!p_state->xml_mode && argcode == ARG_TAGNAME)
-	  sv_lower(arg);
+	  sv_lower(aTHX_ arg);
       }
       break;
 
@@ -272,7 +275,7 @@ report_event(PSTATE* p_state,
 	      beg++; len -= 2;
 	    }
 	    attrval = newSVpvn(beg, len);
-	    decode_entities(attrval, entity2char);
+	    decode_entities(aTHX_ attrval, entity2char);
 	  }
 	  else { /* boolean */
 	    if (p_state->bool_attr_val)
@@ -282,7 +285,7 @@ report_event(PSTATE* p_state,
 	  }
 
 	  if (!p_state->xml_mode)
-	    sv_lower(attrname);
+	    sv_lower(aTHX_ attrname);
 	  if (!hv_store_ent(hv, attrname, attrval, 0)) {
 	    SvREFCNT_dec(attrval);
 	  }
@@ -300,7 +303,7 @@ report_event(PSTATE* p_state,
 	  SV* attrname = newSVpvn(tokens[i].beg,
 				  tokens[i].end-tokens[i].beg);
 	  if (!p_state->xml_mode)
-	    sv_lower(attrname);
+	    sv_lower(aTHX_ attrname);
 	  av_push(av, attrname);
 	}
 	arg = sv_2mortal(newRV_noinc((SV*)av));
@@ -315,7 +318,7 @@ report_event(PSTATE* p_state,
       if (event == E_TEXT) {
 	arg = sv_2mortal(newSVpvn(beg, end - beg));
 	if (!p_state->is_cdata)
-	  decode_entities(arg, entity2char);
+	  decode_entities(aTHX_ arg, entity2char);
       }
       break;
       
@@ -391,6 +394,7 @@ report_event(PSTATE* p_state,
 EXTERN SV*
 argspec_compile(SV* src)
 {
+  dTHX;
   SV* argspec = newSVpvn("", 0);
   STRLEN len;
   char *s = SvPV(src, len);
@@ -467,6 +471,7 @@ argspec_compile(SV* src)
 static void
 flush_pending_text(PSTATE* p_state, SV* self)
 {
+  dTHX;
   bool   old_unbroken_text = p_state->unbroken_text;
   SV*    old_pend_text     = p_state->pend_text;
   bool   old_is_cdata      = p_state->is_cdata;
@@ -590,6 +595,7 @@ parse_comment(PSTATE* p_state, char *beg, char *end, STRLEN offset, SV* self)
 static void
 marked_section_update(PSTATE* p_state)
 {
+  dTHX;
   /* we look at p_state->ms_stack to determine p_state->ms */
   AV* ms_stack = p_state->ms_stack;
   p_state->ms = MS_NONE;
@@ -637,6 +643,7 @@ marked_section_update(PSTATE* p_state)
 static char*
 parse_marked_section(PSTATE* p_state, char *beg, char *end, SV* self)
 {
+  dTHX;
   char *s = beg;
   AV* tokens = 0;
 
@@ -660,7 +667,7 @@ parse_marked_section(PSTATE* p_state, char *beg, char *end, SV* self)
 
     if (!tokens)
       tokens = newAV();
-    av_push(tokens, sv_lower(newSVpvn(name_start, name_end - name_start)));
+    av_push(tokens, sv_lower(aTHX_ newSVpvn(name_start, name_end - name_start)));
   }
   if (*s == '-') {
     s++;
@@ -882,8 +889,6 @@ parse_start(PSTATE* p_state, char *beg, char *end, STRLEN offset, SV* self)
     attr_name_char  = HCTYPE_NOT_SPACE_EQ_GT;
   }
 
-
-  assert(beg[0] == '<' && isHNAME_FIRST(beg[1]) && end - beg > 2);
   s += 2;
 
   while (s < end && isHCTYPE(*s, tag_name_char))
@@ -1096,9 +1101,10 @@ parse_null(PSTATE* p_state, char *beg, char *end, STRLEN offset, SV* self)
 #include "pfunc.h"                   /* declares the parsefunc[] */
 
 EXTERN void
-parse(PSTATE* p_state,
-	   SV* chunk,
-	   SV* self)
+parse(pTHX_
+      PSTATE* p_state,
+      SV* chunk,
+      SV* self)
 {
   char *s, *t, *beg, *end, *new_pos;
   STRLEN len;
